import 'dart:developer';

import 'package:dio/dio.dart';
import 'package:flutter/cupertino.dart';
import 'package:pmu_new/data/mappers/PlaceDataDtoToModel.dart';
import 'package:pretty_dio_logger/pretty_dio_logger.dart';

import '../../models/CardData.dart';
import '../dtos/PlaceDTO.dart';
import 'api_Interface.dart';

class PlacesRepository extends ApiInterface {
  static final Dio _dio = Dio()
    ..interceptors.add(PrettyDioLogger(
      requestHeader: true,
      requestBody: true,
    ));
  static const String _baseUrl = 'http://192.168.184.215:5001';
  //static const String _baseUrl = 'https://localhost:5001';
  @override
  Future<List<CardData>?> loadData({int? q, OnErrorCallback? onError}) async {
    try {
      const String url = '$_baseUrl/api/Main/GetManufactureList';

      final Response<dynamic> response = await _dio.get<Map<dynamic, dynamic>>(
        url,
        queryParameters: q != null ? {'year': q} : null,
      );

      final PlacesDto dto = PlacesDto.fromJson(response.data as Map<String, dynamic>);
      final List<CardData>? data = dto.data?.map((e) => e.toDomain()).toList();
      //debugPrint("length: ${data?.length}");
      return data;
    } on DioException catch (e) {
      onError?.call(e.error?.toString());
      return null;
    }
  }
}
