import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:pmu_new/components/extensions/context_x.dart';
import 'package:pmu_new/presentation/home_page/MyCard.dart';
import 'package:pmu_new/models/CardData.dart';
import 'package:pmu_new/presentation/svg_object.dart';
import '../details_page/details_page.dart';
import '../locale_bloc/locale_bloc.dart';
import '../locale_bloc/locale_event.dart';
import '../locale_bloc/locale_state.dart';
import 'bloc/bloc.dart';
import 'bloc/events.dart';
import 'bloc/state.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import '../../components/utils/debounce.dart';
import 'dart:math' as math;

import 'like_bloc/like_bloc.dart';
import 'like_bloc/like_event.dart';
import 'like_bloc/like_state.dart';

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key, required this.title});

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          backgroundColor: Theme.of(context).colorScheme.inversePrimary,
          title: Text(widget.title),
        ),
        body: const CardWidget());
  }
}

class CardWidget extends StatefulWidget {
  const CardWidget({super.key});

  @override
  State<CardWidget> createState() => _CardWidgetState();
}

class _CardWidgetState extends State<CardWidget> {
  final searchController = TextEditingController();

  @override
  void initState() {
    SvgObjects.init();
    WidgetsBinding.instance.addPostFrameCallback((_) {
      context.read<HomeBloc>().add(const HomeLoadDataEvent());
      context.read<LikeBloc>().add(const LoadLikesEvent());
    });
    super.initState();
  }

  @override
  void dispose() {
    searchController.dispose();
    super.dispose();
  }

  void _showSnackBar(BuildContext context, String title, bool isLiked) {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text(
          '$title ${isLiked ? context.locale.liked : context.locale.disliked}',
          style: Theme.of(context).textTheme.bodyLarge,
        ),
        backgroundColor: Colors.greenAccent,
        duration: const Duration(seconds: 1),
      ));
    });
  }

  void _navToDetails(BuildContext context, CardData data) {
    Navigator.push(
      context,
      CupertinoPageRoute(builder: (context) => DetailsPage(data)),
    );
  }

  Future<void> _onRefresh() {
    context
        .read<HomeBloc>()
        .add(HomeLoadDataEvent(search: int.tryParse(searchController.text)));
    return Future.value(null);
  }
  void _onLike(String? id, String title, bool isLiked) {
    if (id != null) {
      context.read<LikeBloc>().add(ChangeLikeEvent(id));
      _showSnackBar(context, title, !isLiked);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Center(
        child: Padding(
      padding: EdgeInsets.only(top: MediaQuery.of(context).padding.top),
      child: Column(
        children: [
          Row(
            children: [
              Expanded(
                flex: 4,
                child: Padding(
                  padding: const EdgeInsets.all(12),
                  child: CupertinoSearchTextField(
                    controller: searchController,
                    placeholder: context.locale.search,
                    onChanged: (search) {
                      Debounce.run(() => context.read<HomeBloc>().add(
                          HomeLoadDataEvent(search: int.tryParse(search))));
                    },
                  ),
                ),
              ),
              GestureDetector(
                onTap: () =>
                    context.read<LocaleBloc>().add(const ChangeLocaleEvent()),
                child: SizedBox.square(
                  dimension: 50,
                  child: Padding(
                    padding: const EdgeInsets.only(right: 12),
                    child: BlocBuilder<LocaleBloc, LocaleState>(
                      builder: (context, state) {
                        return state.currentLocale.languageCode == 'ru'
                            ? const SvgRu()
                            : const SvgUk();
                      },
                    ),
                  ),
                ),
              ),
            ],
          ),
          BlocBuilder<HomeBloc, HomeState>(
              builder: (context, state) => state.isLoading
                  ? const CircularProgressIndicator()
                  : BlocBuilder<LikeBloc, LikeState>(
                builder: (context, likeState) {
                  return Expanded(
                    child: RefreshIndicator(
                      onRefresh: _onRefresh,
                      child: ListView.builder(
                        padding: EdgeInsets.zero,
                        itemCount: state.data?.length ?? 0,
                        itemBuilder: (context, index) {
                          final data = state.data?[index];
                          return data != null
                              ? MyCard(
                            cardData: data,
                            onlike: _onLike,
                            //id: data.id,
                            isliked: likeState.likedIds?.contains(data.id) == true,
                            onTap: () => _navToDetails(context, data),
                          )
                              : const SizedBox.shrink();
                        },
                      ),
                    ),
                  );
                },))
        ],
      ),
    ));
  }
}
